# TOPSIS

Title: **TOPSIS method for multiple-criteria decision making (MCDM)**.

Version: **1.0.1**.

Author: **Sukhnoor Kaur**.

Description: **Evaluation of alternatives based on multiple criteria using TOPSIS method.**

---

## How to install this package:

```
>> pip install Topsis-Sukhnoor_102003112
```

### In Command Prompt

```
>> topsis 102003112-data "1,2,1,2,1" "+,+,-,-,+" output.csv
```

<br>

The output file will contain columns of input file along with two additional columns having Topsis_score and Rank
